API Reference
=============

This page lists the various classes and functions that ``demcmc`` provides.

.. contents:: Contents
    :depth: 2

Input
-----
.. autoclass:: demcmc.TempBins

.. autofunction:: demcmc.load_cont_funcs

.. autoclass:: demcmc.ContFuncDiscrete

.. autoclass:: demcmc.EmissionLine

Running
-------
.. autofunction:: demcmc.predict_dem_emcee

Output
------
.. autoclass:: demcmc.DEMOutput

.. autoclass:: demcmc.emission.BinnedDEM

.. autofunction:: demcmc.plot_emission_loci
